@@ -1,8 +1,7 @@
 context("Test getLocData")
 
-library(rYoutheria)
-
 test_that("Testing errors and warnings are given", {
+  skip_on_cran()
   expect_warning(test <- getLocData(country = "foo"),
                  regexp = 'No Data returned for this country')
   expect_warning(test <- getLocData(StudyUnitId=12),
@@ -12,6 +11,7 @@ test_that("Testing errors and warnings are given", {
 })
 
 test_that("Testing data is returned", {
+  skip_on_cran()
   expect_is(test <- getLocData(country='India'), 'data.frame')
   expect_equal(ncol(test), 16)
   expect_is(test <- getLocData(StudyUnitId=169), 'data.frame')
